@@ -1,7 +1,11 @@
 format_title <- function(x, width) {
+  align(str_trunc(x, width))
+}
+
+tick_if_needed <- function(x) {
   needs_ticks <- !is_syntactic(x)
   x[needs_ticks] <- tick(x[needs_ticks])
-  str_trunc(x, width)
+  x
 }
 
 is_syntactic <- function(x) {
@@ -11,10 +15,9 @@ is_syntactic <- function(x) {
 }
 
 is_ambiguous_string <- function(x) {
-  grepl("^$|^ | $|\\\\|\"", x)
+  !is.na(x) & grepl("^$|^ | $|\\\\|\"", x)
 }
 
 tick <- function(x) {
-  x[is.na(x)] <- "NA"
-  encodeString(x, quote = "`")
+  ifelse(is.na(x), "NA", encodeString(x, quote = "`"))
 }
